pub struct JsonMessageImpl { /* private fields */ }Expand description
A message implementation that stores structured JSON data.
This is used when you want to pass raw data to a logger that supports structured output (like a database or an ELK stack).
Feature Requirement
Only available when the json feature is enabled.
Implementations